@@ -6,7 +6,7 @@ import pathlib
 from typing import Type
 
 
-def map_discovered_route_to_route(
+def _map_discovered_route_to_route(
     path: pathlib.Path,
 ) -> Type[Route] | None:
     resolved_path = path.resolve()
@@ -33,7 +33,7 @@ def discover_routes(
     potential_routes = {
         RoutePath.from_path(
             path.relative_to(routes_directory).with_suffix("")
-        ): map_discovered_route_to_route(path)
+        ): _map_discovered_route_to_route(path)
         for path in routes_directory.glob("**/*.py")
     }
 
