@@ -11,9 +11,11 @@ def load_local_module(name: str, path: pathlib.Path) -> ModuleType | None:
 
     module = importlib.util.module_from_spec(spec)
 
-    if module is None:
+    try:
+        spec.loader.exec_module(module)
+    except Exception as error:
+        # TODO: Log this somewhere
+        _exception = error
         return None
 
-    spec.loader.exec_module(module)
-
     return module
