@@ -6,6 +6,6 @@ _T = TypeVar("_T", bound=type)
 
 def is_route(value: _T) -> TypeGuard[Type[Route]]:
     try:
-        return issubclass(value, Route) and not value == Route
+        return issubclass(value, Route) and value is not Route
     except TypeError:
         return False
